@@ -21,14 +21,14 @@ static int check_circular_list(odb_data_t const * data)
 	unsigned char * bitmap = malloc(data->descr->current_size);
 	memset(bitmap, '\0', data->descr->current_size);
 
-	for (pos = 0 ; pos < data->descr->size*BUCKET_FACTOR ; ++pos) {
+	for (pos = 0 ; pos < data->descr->size * BUCKET_FACTOR ; ++pos) {
 
 		odb_index_t index = data->hash_base[pos];
 		if (index && !do_abort) {
 			while (index) {
-				if (bitmap[index]) {
+				if (bitmap[index])
 					do_abort = 1;
-				}
+
 				bitmap[index] = 1;
 				index = data->node_base[index].next;
 			}
@@ -43,9 +43,9 @@ static int check_circular_list(odb_data_t const * data)
 			index = data->hash_base[pos];
 			while (index) {
 				printf("%d ", index);
-				if (bitmap[index]) {
+				if (bitmap[index])
 					exit(1);
-				}
+
 				bitmap[index] = 1;
 				index = data->node_base[index].next;
 			}
@@ -77,6 +77,7 @@ static int check_redundant_key(odb_data_t const * data, odb_key_t max)
 		if (bitmap[data->node_base[pos].key]) {
 			printf("redundant key found %lld\n",
 			       (unsigned long long)data->node_base[pos].key);
+			free(bitmap);
 			return 1;
 		}
 		bitmap[data->node_base[pos].key] = 1;
@@ -122,13 +123,11 @@ int odb_check_hash(odb_t const * odb)
 		ret = 1;
 	}
 
-	if (ret == 0) {
+	if (ret == 0)
 		ret = check_circular_list(data);
-	}
 
-	if (ret == 0) {
+	if (ret == 0)
 		ret = check_redundant_key(data, max);
-	}
 
 	return ret;
 }
