@@ -27,12 +27,6 @@
 #include "op_cpu_type.h"
 #include "op_hw_specific.h"
 
-/* A macro to be used for ppc64 architecture-specific code.  The '__powerpc__' macro
- * is defined for both ppc64 and ppc32 architectures, so we must further qualify by
- * including the 'HAVE_LIBPFM' macro, since that macro will be defined only for ppc64.
- */
-#define PPC64_ARCH (HAVE_LIBPFM) && ((defined(__powerpc__) || defined(__powerpc64__)))
-
 struct cpu_descr {
 	char const * pretty;
 	char const * name;
@@ -122,6 +116,11 @@ static struct cpu_descr const cpu_descrs[MAX_CPU_TYPE] = {
 	{ "ARM Cortex-A57", "arm/armv8-ca57", CPU_ARM_V8_CA57, 6},
 	{ "ARM Cortex-A53", "arm/armv8-ca53", CPU_ARM_V8_CA53, 6},
 	{ "Intel Skylake microarchitecture", "i386/skylake", CPU_SKYLAKE, 4 },
+	{ "Intel Goldmont microarchitecture", "i386/goldmont", CPU_GOLDMONT, 4 },
+	{ "IBM z13", "s390/z13", CPU_S390_Z13, 1 },
+	{ "ARM Cortex-A17", "arm/armv7-ca17", CPU_ARM_V7_CA17, 7 },
+	{ "ppc64 POWER9", "ppc64/power9", CPU_PPC64_POWER9, 6 },
+	{ "Intel Knights Landing", "i386/knightslanding", CPU_KNIGHTSLANDING, 4 },
 };
  
 static size_t const nr_cpu_descrs = sizeof(cpu_descrs) / sizeof(struct cpu_descr);
@@ -295,6 +294,8 @@ static op_cpu _try_ppc64_arch_generic_cpu(void)
 			 */
 			if ((strcmp(platform, "power7") == 0) && (strcmp(base_platform, "power8") == 0))
 				cpu_type = CPU_PPC64_POWER8;
+			else if ((strcmp(platform, "power8") == 0) && (strcmp(base_platform, "power9") == 0))
+				cpu_type = CPU_PPC64_POWER9;
 			else
 				cpu_type = CPU_PPC64_ARCH_V1;
 		}
@@ -327,6 +328,11 @@ static op_cpu _get_ppc64_cpu_type(void)
 	if (strncmp(cpu_name_lowercase, "power8e", 7) == 0)
 		cpu_name_lowercase[6] = '\0';
 
+	/* The POWER8NV and POWER8NVL variants have the same core PMU events as
+	 * POWER8. */
+	if (strncmp(cpu_name_lowercase, "power8nv", 8) == 0)
+		cpu_name_lowercase[6] = '\0';
+
 	cpu_type_str[0] = '\0';
 	strcat(cpu_type_str, "ppc64/");
 	strncat(cpu_type_str, cpu_name_lowercase, len);
@@ -411,6 +417,8 @@ static op_cpu _get_arm_cpu_type(void)
 			return op_get_cpu_number("arm/armv7-ca9");
 		case 0xc0f:
 			return op_get_cpu_number("arm/armv7-ca15");
+		case 0xc0e:
+			return op_get_cpu_number("arm/armv7-ca17");
 		case 0xd07:
 			return op_get_cpu_number("arm/armv8-ca57");
 		case 0xd03:
@@ -666,19 +674,20 @@ static op_cpu _get_s390_cpu_type(void)
 		return CPU_NO_GOOD;
 
 	ptr += sizeof(prefix) - 1;
-	if (sscanf(ptr, "%u", &model) != 1)
-		return CPU_NO_GOOD;
+	model = strtol(ptr, NULL, 16);
 
 	switch (model) {
-	case 2097:
-	case 2098:
+	case 0x2097:
+	case 0x2098:
 		return CPU_S390_Z10;
-	case 2817:
-	case 2818:
+	case 0x2817:
+	case 0x2818:
 		return CPU_S390_Z196;
-	case 2827:
-	case 2828:
+	case 0x2827:
+	case 0x2828:
 		return CPU_S390_ZEC12;
+	case 0x2964:
+		return CPU_S390_Z13;
 	}
 	return CPU_NO_GOOD;
 }
@@ -739,10 +748,12 @@ op_cpu op_cpu_base_type(op_cpu cpu_type)
 	case CPU_HASWELL:
 	case CPU_BROADWELL:
 	case CPU_SKYLAKE:
+	case CPU_GOLDMONT:
 	case CPU_SILVERMONT:
 	case CPU_WESTMERE:
 	case CPU_SANDYBRIDGE:
 	case CPU_IVYBRIDGE:
+	case CPU_KNIGHTSLANDING:
 		return CPU_ARCH_PERFMON;
 	default:
 		/* assume processor in a class by itself */
