@@ -89,7 +89,8 @@ typedef enum {
 	CPU_ARM_V7_CA7, /**< ARM Cortex-A7 */
 	CPU_ARM_V7_CA15, /**< ARM Cortex-A15 */
 	CPU_HASWELL, /** < Intel Haswell microarchitecture */
-	CPU_S390_ZEC12, /**< IBM zEnterprise EC12 */	CPU_AMD64_GENERIC, /**< AMD64 Generic */
+	CPU_S390_ZEC12, /**< IBM zEnterprise EC12 */
+	CPU_AMD64_GENERIC, /**< AMD64 Generic */
 	CPU_PPC64_ARCH_V1, /** < IBM Power architected events version 1 */
 	CPU_PPC64_POWER8, /**< ppc64 POWER8 family */
 	CPU_PPC_E500MC, /**< e500mc */
@@ -100,9 +101,23 @@ typedef enum {
 	CPU_BROADWELL, /** < Intel Broadwell (Core-M) microarchitecture */
 	CPU_ARM_V8_CA57, /* ARM Cortex-A57 */
 	CPU_ARM_V8_CA53, /* ARM Cortex-A53 */
+	CPU_SKYLAKE, /** < Intel Skylake microarchitecture */
+	CPU_GOLDMONT, /** < Intel Goldmont microarchitecture */
+	CPU_S390_Z13, /** < IBM z13 */
+	CPU_ARM_V7_CA17, /* ARM Cortex-A17 */
+	CPU_PPC64_POWER9, /**< ppc64 POWER8 family */
+	CPU_KNIGHTSLANDING, /** Intel Knights Landing microarchitecture */
 	MAX_CPU_TYPE
 } op_cpu;
 
+/* A macro to be used for ppc64 architecture-specific code.  The '__powerpc__' macro
+ * is defined for both ppc64 and ppc32 architectures, so we must further qualify by
+ * including the 'HAVE_LIBPFM' macro, since that macro will be defined only for ppc64.
+ */
+#if  defined(HAVE_LIBPFM) && ((defined(__powerpc__) || defined(__powerpc64__)))
+#define PPC64_ARCH 1
+#endif
+
 /**
  * the CPU lowest common denominator
  *
