@@ -174,6 +174,8 @@ int op_pe_utils::op_check_perf_events_cap(bool use_cpu_minus_one)
         memset(&attr, 0, sizeof(attr));
         attr.size = sizeof(attr);
         attr.sample_type = PERF_SAMPLE_IP;
+	/* avoid kernel events so test works when perf_event_paranoid = 2 */
+	attr.exclude_kernel =1;
 
 	pid = getpid();
 	syscall(__NR_perf_event_open, &attr, pid, cpu_to_try, -1, 0);
@@ -559,7 +561,8 @@ static string _handle_powerpc_event_spec(string event_spec)
 	grp_pos = evt.rfind("_GRP");
 	if ((grp_pos != string::npos) && ((evt = evt.substr(grp_pos, string::npos))).length() > 4) {
 		char * end;
-		strtoul(evt.substr(4, string::npos).c_str(), &end, 0);
+		unsigned long dummy __attribute__ ((__unused__));
+		dummy = strtoul(evt.substr(4, string::npos).c_str(), &end, 0);
 		if (end && (*end == '\0')) {
 		// Valid group number found after _GRP, so we can skip to the end.
 			event_found = true;
