@@ -544,6 +544,7 @@ int main(int argc, char const * argv[])
 	case CPU_BROADWELL:
 	case CPU_SKYLAKE:
 	case CPU_SILVERMONT:
+	case CPU_GOLDMONT:
 	case CPU_WESTMERE:
 	case CPU_SANDYBRIDGE:
 	case CPU_IVYBRIDGE:
@@ -553,6 +554,12 @@ int main(int argc, char const * argv[])
 			"Intel Architecture Optimization Reference Manual\n\n";
 		break;
 
+	case CPU_KNIGHTSLANDING:
+		event_doc =
+			"See Intel Xeon Phi(TM) Processor Performance Monitoring Reference and\n"
+			"Intel Architecture Optimization Reference Manual\n\n";
+		break;
+
 	case CPU_ARCH_PERFMON:
 		event_doc =
 			"See Intel 64 and IA-32 Architectures Software Developer's Manual\n"
@@ -629,6 +636,12 @@ int main(int argc, char const * argv[])
 			"Cortex A15 DDI (ARM DDI 0438F, revision r3p1)\n";
 		break;
 
+	case CPU_ARM_V7_CA17:
+		event_doc =
+			"See Cortex-A17 MPCore Technical Reference Manual\n"
+			"Cortex A17 DDI (ARM DDI 0535C, revision r1p1)\n";
+		break;
+
 	case CPU_ARM_V8_APM_XGENE:
 		event_doc =
 			"See ARM Architecture Reference Manual \n"
@@ -670,7 +683,17 @@ int main(int argc, char const * argv[])
 	case CPU_PPC64_POWER8:
 		event_doc =
 			"This processor type is fully supported with operf.\n"
-			"See Power ISA 2.07 at https://www.power.org/\n\n";
+			"See Power ISA 3.0B at "
+			"https://openpowerfoundation.org/?submit=Search&s=ISA \n"
+			"And the P8 Users Manual at "
+			"https://www-355.ibm.com/systems/power/openpower \n\n";
+		break;
+
+	case CPU_PPC64_POWER9:
+		event_doc =
+			"This processor type is fully supported with operf.\n"
+			"See Power ISA 3.0B at "
+			"https://openpowerfoundation.org/?resource_lib=power-isa-version-3-0\n";
 		break;
 
 	case CPU_MIPS_20K:
@@ -778,6 +801,7 @@ int main(int argc, char const * argv[])
 	case CPU_S390_Z10:
 	case CPU_S390_Z196:
 	case CPU_S390_ZEC12:
+	case CPU_S390_Z13:
 		event_doc = "IBM System z CPU Measurement Facility\n"
 				"http://www-01.ibm.com/support/docview.wss"
 				"?uid=isg26fcd1cc32246f4c8852574ce0044734a\n";
